paulicirc.builders
==================

.. automodule:: paulicirc.builders

CircuitBuilder
--------------

.. autoclass:: paulicirc.builders.CircuitBuilder
    :show-inheritance:
    :members:

CircuitBuilderBase
------------------

.. autoclass:: paulicirc.builders.CircuitBuilderBase
    :show-inheritance:
    :members:
    :special-members: __new__

LayeredCircuitBuilder
---------------------

.. autoclass:: paulicirc.builders.LayeredCircuitBuilder
    :show-inheritance:
    :members:

PHASE_NBYTES
------------

.. autodata:: paulicirc.builders.PHASE_NBYTES

PhaseLike
---------

.. autodata:: paulicirc.builders.PhaseLike

QubitIdx
--------

.. autoclass:: paulicirc.builders.QubitIdx
    :show-inheritance:
    :members:
